##############################
@{{ program }}@ - TIS analysis
##############################

TIS analysis report generated by @{{ program }}@ version @{{ version }}@
on @{{ date }}@.

Please note that the flux (and thus the rate constant)
was **not** calculated in this analysis!

The main result is:

* The crossing probability:
  :math:`P_{\text{cross}} = @{{ numbers['pcross'] }}@  \pm  @{{ numbers['perr'] }}@ \%`

Detailed results are given below for the different path
ensembles and the overall results are summarized
in the `Combined results`_.

.. _figure-results:

Results for path ensembles
==========================

The following interfaces were used in the simulation and in
the analysis:

@{{ tables['interfaces'] }}@

The calculated crossing probabilities are:

@{{ tables['probability'] }}@

The crossing probabilities are also displayed in the figures below

.. _prob-figures-output:

Crossing probabilities
----------------------

@{% for figure in figures['tis'] %}@
.. image:: @{{ figure['pcross'] }}@
   :width: 30%
.. image:: @{{ figure['prun'] }}@
   :width: 30%
.. image:: @{{ figure['perror'] }}@
   :width: 30%
@{% endfor %}@


.. _len-shoot-figures-output:

Distributions for path lengths and shooting moves
-------------------------------------------------

The average path lengths in the different ensembles are given in
the table below and some distributions for the path lengths and
shooting moves can also be found here:

@{{ tables['path'] }}@

@{% for figure in figures['tis'] %}@
.. image:: @{{ figure['lpath'] }}@
   :width: 30%
.. image:: @{{ figure['shoots'] }}@
   :width: 30%
.. image:: @{{ figure['shoots_scaled'] }}@
   :width: 30%
@{% endfor %}@


.. _tis-efficiency:

Efficiency analysis
-------------------

@{{ tables['efficiency'] }}@

.. _combined-results:

Combined results
================

The overall matched probability is shown in the left figure below
and the indivitual matched probabilities are shown in the right figure:

.. image:: @{{ figures['total'] }}@
   :width: 45%
.. image:: @{{ figures['matched']}}@
   :width: 45%

The overall crossing probability is:
:math:`P_{\text{cross}} = @{{ numbers['pcross'] }}@  \pm  @{{ numbers['perr'] }}@ \%`

Other statistics:

* :math:`\text{sim.time} = @{{ numbers['simt'] }}@`

* :math:`\tau_{\text{eff}} = @{{ numbers['teff']}}@`

* :math:`\tau_{\text{eff}}^{\text{opt}} = @{{ numbers['opteff']}}@`
